foreign

package
v0.36.3 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 5, 2026 License: Apache-2.0 Imports: 0 Imported by: 0

Documentation

Overview

Package foreign declares a type sharing its name with an enum type of the parent package, so the membership test cannot be name-only.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Weekday

type Weekday int

Weekday is unrelated to constforms.Weekday beyond the name.

const TheThirteenth Weekday = 13

TheThirteenth is a member of THIS Weekday, not of the annotated enum next door.

Jump to